@@ -141,7 +141,7 @@ namespace Oxygen
 
         #if ENABLE_INNER_SHADOWS_HACK
         if(!getenv("OXYGEN_DISABLE_INNER_SHADOWS_HACK"))
-            _innerShadowHook.connect( "realize", (GSignalEmissionHook)innerShadowHook, this );
+        { _innerShadowHook.connect( "realize", (GSignalEmissionHook)innerShadowHook, this ); }
         #endif
 
         _sizeAllocationHook.connect( "size-allocate", (GSignalEmissionHook)sizeAllocationHook, this );
@@ -354,7 +354,10 @@ namespace Oxygen
         Animations& animations( *static_cast<Animations*>(data) );
         if( !animations.innerShadowsEnabled() ) return TRUE;
 
+        // blacklist
         if( Gtk::g_object_is_a( G_OBJECT( widget ), "SwtFixed" ) ) return TRUE;
+        if( Gtk::g_object_is_a( G_OBJECT( widget ), "GtkPizza" ) ) return TRUE;
+        if( Gtk::g_object_is_a( G_OBJECT( widget ), "MessageList") ) return TRUE;
 
         GtkWidget* parent(gtk_widget_get_parent(widget));
         if( !GTK_IS_SCROLLED_WINDOW( parent ) ) return TRUE;
