@@ -26,6 +26,8 @@
 #include "oxygentimeline.h"
 #include "config.h"
 
+#include <glib.h>
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
 
 #include <algorithm>
@@ -69,6 +71,7 @@ namespace Oxygen
         _menuHighlightMode( MM_DARK ),
         _windowDragEnabled( true ),
         _windowDragMode( WD_FULL ),
+        _useWMMoveResize( true ),
         _startDragDist( 4 ),
         _startDragTime( 500 ),
         _animationsEnabled( true ),
@@ -208,30 +211,7 @@ namespace Oxygen
 
     //_________________________________________________________
     bool QtSettings::runCommand( const std::string& command, char*& result ) const
-    {
-
-        if( FILE* fp = popen( command.c_str(), "r" ) )
-        {
-
-            // read command output. Make sure that the buffer is large enough to read the entire
-            // output, by multiplying its initial size by two as long as the last character is not '\n'
-            // note that the allocated string must be freed by the calling method
-            gulong bufSize=512;
-            size_t currentOffset=0;
-            result= static_cast<char*>(g_malloc(bufSize));
-            while( fgets( result+currentOffset, bufSize-currentOffset, fp ) && result[strlen(result)-1] != '\n' )
-            {
-                currentOffset = bufSize-1;
-                bufSize *= 2;
-                result = static_cast<char*>( g_realloc( result, bufSize ) );
-            }
-
-            pclose(fp);
-            return true;
-
-        } else return false;
-
-    }
+    { return g_spawn_command_line_sync( command.c_str(), &result, 0L, 0L, 0L ) && result; }
 
     //_________________________________________________________
     bool QtSettings::loadKdeGlobals( void )
@@ -347,7 +327,15 @@ namespace Oxygen
         // make sure that corresponding directory does exist
         struct stat st;
         if( stat( _userConfigDir.c_str(), &st ) != 0 )
-        { mkdir( _userConfigDir.c_str(), S_IRWXU|S_IRWXG|S_IRWXO ); }
+        {
+            #ifdef G_OS_WIN32
+            // S_IRWXG and S_IRWXO are undefined on Windows, and g_mkdir()
+            // ignores its second parameter on Windows anyway.
+            g_mkdir( _userConfigDir.c_str(), 0 );
+            #else
+            g_mkdir( _userConfigDir.c_str(), S_IRWXU|S_IRWXG|S_IRWXO );
+            #endif
+        }
 
         // note: in some cases, the target might exist and not be a directory
         // nothing we can do about it. We won't overwrite the file to prevent dataloss
@@ -681,6 +669,7 @@ namespace Oxygen
         _css.setCurrentSection( Gtk::CSS::defaultSection() );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Window ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::WindowText ) ) );
+        addLinkColors( "[Colors:Window]" );
 
         _css.addSection( "*:selected" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Selected ) ) );
@@ -705,6 +694,7 @@ namespace Oxygen
             "GtkEntry" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Base ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Text ) ) );
+        addLinkColors( "[Colors:View]" );
 
         _css.addSection(
             ".view:insensitive, "
@@ -733,6 +723,7 @@ namespace Oxygen
          // buttons and comboboxes
         _css.addSection( "GtkButton" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Button ) ) );
+        addLinkColors( "[Colors:Button]" );
 
         _css.addSection( "GtkButton:insensitive" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Disabled, Palette::Button ) ) );
@@ -763,6 +754,7 @@ namespace Oxygen
 
         _css.addSection( "GtkWindow#gtk-tooltip GtkLabel" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::TooltipText ) ) );
+        addLinkColors( "[Colors:Tooltip]" );
 
         // rubber band selection (at least for nautilus)
         // FIXME: is Palette::Selected the proper color? Is 0.35 the proper alpha?
@@ -796,6 +788,20 @@ namespace Oxygen
 
     }
 
+    //_________________________________________________________
+    void QtSettings::addLinkColors( const std::string& section )
+    {
+
+        // link colors
+        const ColorUtils::Rgba linkColor( ColorUtils::Rgba::fromKdeOption( _kdeGlobals.getValue( section, "ForegroundLink" ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( "-GtkWidget-link-color", linkColor ) );
+
+        // visited link colors
+        const ColorUtils::Rgba visitedLinkColor( ColorUtils::Rgba::fromKdeOption( _kdeGlobals.getValue( section, "ForegroundVisited" ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( "-GtkWidget-visited-link-color", visitedLinkColor ) );
+
+    }
+
     //_________________________________________________________
     void QtSettings::loadKdeFonts( void )
     {
@@ -969,6 +975,9 @@ namespace Oxygen
         if( windowDragMode == "WD_MINIMAL" ) _windowDragMode = WD_MINIMAL;
         else _windowDragMode = WD_FULL;
 
+        // use window manager to handle window drag
+        _useWMMoveResize = _oxygen.getOption( "[Style]", "UseWMMoveResize" ).toVariant<std::string>("true") == "true";
+
         // animations
         _animationsEnabled = ( _oxygen.getOption( "[Style]", "AnimationsEnabled" ).toVariant<std::string>("true") == "true" );
         _genericAnimationsEnabled = ( _oxygen.getOption( "[Style]", "GenericAnimationsEnabled" ).toVariant<std::string>("true") == "true" );
