@@ -192,6 +192,10 @@ namespace Oxygen
         WindowDragMode windowDragMode( void ) const
         { return _windowDragMode; }
 
+        //! use window manager to handle move-resize
+        bool useWMMoveResize( void ) const
+        { return _useWMMoveResize; }
+
         //! drag distance
         int startDragDist( void ) const
         { return _startDragDist; }
@@ -388,6 +392,9 @@ namespace Oxygen
         /*! generates an RC string and pass it to gtk */
         void generateGtkColors( void );
 
+        //! add Html link colors to RC's current section
+        void addLinkColors( const std::string& );
+
         //! load fonts from kdeglobals and pass to gtk
         void loadKdeFonts( void );
 
@@ -507,6 +514,9 @@ namespace Oxygen
         //! window drag mode
         WindowDragMode _windowDragMode;
 
+        //! use window manager to handle window grab
+        bool _useWMMoveResize;
+
         //! drag distance
         int _startDragDist;
 
